==> openGion6.2.0.0_dev.zip: uap/webapps/gf/db/mysql/sql/install/01_TABLE/GF84S.sql <==
/****************************************************************************/
/* GF84 ( 移行DB一覧 )                                                      */
/*                                                                          */
/* Created : 2014/12/27 18:21:07                                            */
/****************************************************************************/
CREATE TABLE GF84 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL                        /*  10 ｼｽﾃﾑID       */
 , TABLE_NAME   VARCHAR (  50 )                 NOT NULL                        /*  30 ﾃｰﾌﾞﾙ名      */
 , NAME_JA      VARCHAR ( 200 )                                                 /*  40 名称         */
 , SUIKOU       INTEGER             DEFAULT 0   NOT NULL                        /*  50 移行件数     */
 , NOJUN        INTEGER             DEFAULT 0   NOT NULL                        /*  60 対応順       */
 , CDIKOU       VARCHAR (   1 )     DEFAULT '0' NOT NULL                        /*  70 移行方法     */
 , F_TABLE_NAME VARCHAR (  50 )                                                 /*  90 元ﾃｰﾌﾞﾙ名    */
 , F_NAME_JA    VARCHAR ( 200 )                                                 /* 100 元名称       */
 , F_FILEPATH   VARCHAR ( 256 )                                                 /* 110 元ﾌｧｲﾙﾊﾟｽ    */
 , F_SUIKOU     INTEGER             DEFAULT 0   NOT NULL                        /* 120 元移行件数   */
 , DESCRIPTION  TEXT                                                            /* 130 概要説明     */
 , UNIQ         BIGINT                          NOT NULL    AUTO_INCREMENT      /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL                        /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (  14 )                                                 /* 820 登録日時     */
 , PGSET        VARCHAR (  10 )                                                 /* 830 作成PG       */
 , PGPSET       VARCHAR (  10 )                                                 /* 840 作成親PG     */
 , USRSET       VARCHAR (  10 )                                                 /* 850 作成社員     */
 , DYUPD        VARCHAR (  14 )                                                 /* 860 更新日時     */
 , PGUPD        VARCHAR (  10 )                                                 /* 870 更新PG       */
 , PGPUPD       VARCHAR (  10 )                                                 /* 880 更新親PG     */
 , USRUPD       VARCHAR (  10 )                                                 /* 890 更新者       */
);

==> openGion6.4.0.3_dev.zip: uap/webapps/gf/db/mysql/sql/install/01_TABLE/GF84S.sql <==
/****************************************************************************/
/* GF84 ( 移行DB一覧 )                                                      */
/*                                                                          */
/* Created : 2015/11/16 16:20:08                                            */
/****************************************************************************/
CREATE TABLE GF84 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL                        /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR (   1 )                 NOT NULL                        /*  20 ﾃｰﾌﾞﾙ種別    */
 , TABLE_NAME   VARCHAR (  50 )                 NOT NULL                        /*  30 ﾃｰﾌﾞﾙ名      */
 , NAME_JA      VARCHAR ( 200 )                                                 /*  40 名称         */
 , SUIKOU       INTEGER             DEFAULT 0   NOT NULL                        /*  50 移行件数     */
 , NOJUN        INTEGER             DEFAULT 0   NOT NULL                        /*  60 対応順       */
 , CDIKOU       VARCHAR (   1 )     DEFAULT '0' NOT NULL                        /*  70 移行方法     */
 , F_SYSTEM_ID  VARCHAR (  10 )                                                 /*  80 元ｼｽﾃﾑID     */
 , F_TABLE_NAME VARCHAR (  50 )                                                 /*  90 元ﾃｰﾌﾞﾙ名    */
 , F_NAME_JA    VARCHAR ( 200 )                                                 /* 100 元名称       */
 , F_FILEPATH   VARCHAR ( 256 )                                                 /* 110 元ﾌｧｲﾙﾊﾟｽ    */
 , F_SUIKOU     INTEGER             DEFAULT 0   NOT NULL                        /* 120 元移行件数   */
 , DESCRIPTION  TEXT                                                            /* 130 概要説明     */
 , UNIQ         BIGINT                          NOT NULL    AUTO_INCREMENT      /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL                        /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (  14 )                                                 /* 820 登録日時     */
 , PGSET        VARCHAR (  10 )                                                 /* 830 作成PG       */
 , PGPSET       VARCHAR (  10 )                                                 /* 840 作成親PG     */
 , USRSET       VARCHAR (  10 )                                                 /* 850 作成社員     */
 , DYUPD        VARCHAR (  14 )                                                 /* 860 更新日時     */
 , PGUPD        VARCHAR (  10 )                                                 /* 870 更新PG       */
 , PGPUPD       VARCHAR (  10 )                                                 /* 880 更新親PG     */
 , USRUPD       VARCHAR (  10 )                                                 /* 890 更新者       */
);
